@@ -1,5 +1,4 @@
-r.fgt.sub <-
-function(x.sub, x, weight.sub, weight, k, alpha){
+r.fgt.sub <- function(x.sub, x, weight.sub, weight, k, alpha){
   n <- length(x)
   if(is.null(weight)){
     weight <- rep(1, n)
@@ -7,6 +6,6 @@ function(x.sub, x, weight.sub, weight, k, alpha){
   }
   rhow <- k*weighted.median(x, weight)
   ind <- ifelse(x.sub > rhow, 1, 0)
-  r.fgt <- sum(((((x.sub - rhow)/x.sub)*ind)*weight.sub)^alpha)/sum(weight.sub)
+  r.fgt <- sum(((((x.sub - rhow)/rhow)*ind)^alpha*weight.sub))/sum(weight.sub)
   return(r.fgt)
 }
